@@ -1,22 +1,22 @@
+from importlib import metadata
 import json
+from pathlib import Path
 import shutil
 import subprocess
 import sys
-from importlib import metadata
-from pathlib import Path
-from typing import Any, Optional
+from typing import Annotated, Any
 
 import click
-import typer
 from jinja2 import Environment, FileSystemLoader
 from rich import print
 from rich.prompt import IntPrompt, Prompt
-from typing_extensions import Annotated
+import typer
 
 from nesso_cli.models.common import call_shell, wrapper_context_settings
 from nesso_cli.models.config import config, yaml
 from nesso_cli.models.models import NessoDBTConfig, dbt_config_map
 
+
 app = typer.Typer()
 
 
@@ -49,6 +49,7 @@ def render_string(template_string: str, **kwargs) -> str:
 
     Returns:
         str: The rendered string.
+
     """
     template = JINJA_ENVIRONMENT.from_string(template_string)
     return template.render(**kwargs)
@@ -74,6 +75,7 @@ def render_jinja_template_file(
             `my_project.yml`).
             Ignored if `stream_output` is True.
         stream_output (bool, optional): Whether to return the output as a string.
+
     """
     template = JINJA_ENVIRONMENT.get_template(str(template_path))
     content = template.render(**kwargs)
@@ -114,6 +116,7 @@ def create_profiles_yml_template(
             to "profiles.yml.example".
         kwargs: dict[str, Any]: Values to be passed to the template file (useful to
             execute the function non-interactively).
+
     """
     if profiles_path is None:
         profiles_path = f"{project_name}/profiles.yml.example"
@@ -124,7 +127,7 @@ def create_profiles_yml_template(
         path_trimmed = path.relative_to(path.parent.parent)
         print(f"File '{path_trimmed}' already exists. Overwriting...")
 
-    model = NessoDBTConfig(db_type=db_type, project_name=project_name).dict(  # type: ignore[attr-defined]  # noqa: E501
+    model = NessoDBTConfig(db_type=db_type, project_name=project_name).dict(  # type: ignore[attr-defined]
         by_alias=True
     )
     profile_name = list(model.keys())[0]
@@ -180,6 +183,7 @@ def create_directory_structure(
     Returns:
         tuple[Path, Path, Path]: Paths to the created directories (bronze schema,
             silver schema, gold layer, and nesso config dir).
+
     """
     bronze_schema_dir = project_dir / "models" / "sources" / bronze_schema
     bronze_schema_dir.mkdir(parents=True, exist_ok=True)
@@ -227,8 +231,8 @@ def render_project_files(
         nesso_cli_version (str): The version of nesso CLI used by the project.
         luma (bool): Whether to enable Luma Data Catalog integration.
         snakecase_columns (bool): Whether to standardize column names to snakecase.
-    """
 
+    """
     project_variables = {
         "project_name": project_name,
         "data_architecture": data_architecture,
@@ -274,7 +278,7 @@ def project(
         ),
     ] = config.database_type,
     db_kwargs: Annotated[
-        Optional[str],
+        str | None,
         typer.Option(
             "--db-kwargs", "-k", help="The parameters to pass to the database config"
         ),
@@ -325,7 +329,7 @@ def project(
         ),
     ] = False,
 ):
-    """Initialize a new nesso-models project. :rocket:
+    """Initialize a new nesso-models project :rocket:.
 
     -----------------------------------------
 
@@ -371,6 +375,7 @@ def project(
             standardize column names to snakecase.
         no_install_dependencies (Annotated[bool, typer.Option], optional): Whether to
             skip installing project dependencies.
+
     """
     # There is no good way to provide empty input in Typer, so we have to handle
     # various options.
@@ -438,7 +443,7 @@ def project(
 
 
 #################
-### user init ### # noqa
+### user init ###
 #################
 def _generate_user_profile(
     template_profiles_yml_path: str | Path = "profiles.yml.example",
@@ -526,6 +531,13 @@ def user(
             is_flag=True,
         ),
     ] = False,
+    no_generate_profiles: Annotated[
+        bool,
+        typer.Option(
+            "--no-generate-profiles",
+            is_flag=True,
+        ),
+    ] = False,
 ) -> None:
     """Create a user config and install any necessary packages.
 
@@ -543,35 +555,36 @@ def user(
 
         return k, v
 
-    # Construct kwargs from a list of args in the format
-    # ["--param1", "value1", ...].
-    kwargs = {
-        process_arg(arg)[0]: process_arg(arg)[1]
-        for arg in zip(ctx.args[::2], ctx.args[1::2])
-    }
+    if not no_generate_profiles:
+        # Construct kwargs from a list of args in the format
+        # ["--param1", "value1", ...].
+        kwargs = {
+            process_arg(arg)[0]: process_arg(arg)[1]
+            for arg in zip(ctx.args[::2], ctx.args[1::2], strict=False)
+        }
 
-    profile = _generate_user_profile(**kwargs)
+        profile = _generate_user_profile(**kwargs)
 
-    profiles_path = str(Path(profiles_path).expanduser().resolve())
+        profiles_path = str(Path(profiles_path).expanduser().resolve())
 
-    if Path(profiles_path).exists():
-        with open(profiles_path, "r") as file:
-            profiles = yaml.load(file)
-        profiles.update(profile)
-    else:
-        profiles = profile
+        if Path(profiles_path).exists():
+            with open(profiles_path) as file:
+                profiles = yaml.load(file)
+            profiles.update(profile)
+        else:
+            profiles = profile
 
-    profile_name = list(profile.keys())[0]
-    print(
-        f"Creating user profile '{profile_name}' in [bright_black]{profiles_path}[/]..."
-    )
+        profile_name = list(profile.keys())[0]
+        print(
+            f"Creating user profile '{profile_name}' in [bright_black]{profiles_path}[/]..."
+        )
 
-    # Ensure that the output directory exists.
-    Path(profiles_path).parent.mkdir(parents=True, exist_ok=True)
+        # Ensure that the output directory exists.
+        Path(profiles_path).parent.mkdir(parents=True, exist_ok=True)
 
-    with open(profiles_path, "w") as file:
-        yaml.dump(profiles, file)
-    print("User profile has been created [green]successfully[/].")
+        with open(profiles_path, "w") as file:
+            yaml.dump(profiles, file)
+        print("User profile has been created [green]successfully[/].")
 
     _run_dbt_cmd(
         "debug",
