@@ -1,6 +1,6 @@
 from enum import Enum
 from pathlib import Path
-from typing import Any, Optional, Tuple, Union
+from typing import Any, Literal
 
 from pydantic import BaseModel, Field, create_model
 
@@ -23,7 +23,7 @@ class ColumnMeta(BaseNessoModel):
     data_type: str
     description: str = ""
     quote: bool = True
-    tests: Optional[list[str]] = None
+    tests: list[str] | None = None
     tags: list[str] = []
 
 
@@ -31,7 +31,7 @@ class SourceTable(BaseNessoModel):
     name: str
     description: str = ""
     loaded_at_field: str = "_viadot_downloaded_at_utc::timestamp"
-    freshness: dict[str, dict[str, Union[int, str]]] = {
+    freshness: dict[str, dict[str, int | str]] = {
         "warn_after": {"count": 24, "period": "hour"},
         "error_after": {"count": 48, "period": "hour"},
     }
@@ -50,7 +50,7 @@ class Model(BaseNessoModel):
 class Source(BaseNessoModel):
     name: str
     schema_: str = Field(alias="schema")
-    description: Optional[str] = None
+    description: str | None = None
     tables: list[SourceTable]
 
 
@@ -92,6 +92,11 @@ class DBTPostgresConfig(DBTDatabaseConfig):
 
 class DBTRedshiftConfig(DBTPostgresConfig):
     db_type: str = Field(default="redshift", alias="type")
+    method: Literal["database", "sso"] = "database"
+    scope: str | None = None
+    client_id: str | None = None
+    idp_tenant: str | None = None
+    sso_cache: bool = True
 
 
 class DBTDatabricksConfig(DBTDatabaseConfig):
@@ -160,8 +165,8 @@ def get_dbt_config_class(dbt_db_type: str) -> DBTDatabaseConfig:
     Returns:
         DBTDatabaseConfig: The pydantic model for the configuration
             of the specified database.
-    """
 
+    """
     if dbt_db_type not in dbt_config_map:
         raise NotImplementedError(f"Unsupported database type: '{dbt_db_type}'.")
 
@@ -172,8 +177,8 @@ def get_dbt_config_class(dbt_db_type: str) -> DBTDatabaseConfig:
 class ModelColumnsMetadata(BaseModel):
     quote: bool
     data_type: str
-    description: Optional[str]
-    tests: Optional[list[str]]
+    description: str | None
+    tests: list[str] | None
     tags: list[str]
 
 
@@ -183,7 +188,7 @@ class DBTResourceType(Enum):
 
 
 class DBTProperties(dict):
-    def __init__(self, file_path: Union[str, Path]):
+    def __init__(self, file_path: str | Path):
         self.file_path = file_path
         self.__resource_type = None
         self._load_properties()
@@ -191,7 +196,7 @@ class DBTProperties(dict):
 
     def _load_properties(self):
         """Load dbt properties from the specified YAML file."""
-        with open(self.file_path, "r") as file:
+        with open(self.file_path) as file:
             yaml_dict = yaml.load(file)
 
         for key in yaml_dict:
@@ -204,12 +209,11 @@ class DBTProperties(dict):
         if DBTResourceType.SOURCE.value in self:
             self.__resource_type = DBTResourceType.SOURCE.value
             return self.__resource_type
-        elif DBTResourceType.MODEL.value in self:
+        if DBTResourceType.MODEL.value in self:
             self.__resource_type = DBTResourceType.MODEL.value
             return self.__resource_type
-        else:
-            msg = "Unsupported dbt resource type (must be either a source or a model)."
-            raise ValueError(msg)
+        msg = "Unsupported dbt resource type (must be either a source or a model)."
+        raise ValueError(msg)
 
     def set_yaml_content(self):
         """Write the content of a dictionary to a YAML file."""
@@ -228,6 +232,7 @@ class DBTProperties(dict):
         Args:
             desired_order (list[str]): List of column names in the desired order.
             table_name (str): Name of the table to reorder columns in.
+
         """
 
         def custom_sort(item):
@@ -255,6 +260,7 @@ class DBTProperties(dict):
         Returns:
             columns_dict_metadata (dict[str, ModelColumnsMetadata]): A dictionary
                 containing columns and their metadata.
+
         """
         # Checks the validity of dbt properties
         if self.__modification_time != self.file_path.stat().st_mtime:
@@ -296,9 +302,9 @@ class DBTProperties(dict):
     def coherence_scan(
         self,
         table_name: str,
-        schema_name: Optional[str] = None,
-        env: Optional[str] = None,
-    ) -> Tuple[dict[str, str], dict[str, ModelColumnsMetadata], dict[str, str]]:
+        schema_name: str | None = None,
+        env: str | None = None,
+    ) -> tuple[dict[str, str], dict[str, ModelColumnsMetadata], dict[str, str]]:
         """Get differences between the model metadata in the YAML file and the database.
 
         Args:
@@ -319,6 +325,7 @@ class DBTProperties(dict):
                         from the YAML file.
                     3. db_columns (dict[str, str]): A dictionary representing columns
                         from the database.
+
         """
         yaml_columns_metadata = self.get_yaml_table_columns(table_name=table_name)
 
@@ -344,7 +351,7 @@ class DBTProperties(dict):
         description: str = "",
         tags: list[str] = [],
         quote: bool = True,
-        tests: Optional[list[str]] = None,
+        tests: list[str] | None = None,
     ) -> None:
         """Add a new column to a model in a YAML file.
 
@@ -361,6 +368,7 @@ class DBTProperties(dict):
                 Defaults to True.
             tests (list[str] or None, optional): List of tests associated
                 with the column. Defaults to None.
+
         """
         metadata = {
             "name": column_name,
@@ -394,8 +402,8 @@ class DBTProperties(dict):
         Args:
             table_name (str): Name of the table from which the column will be deleted.
             column_name (str): Name of the column to be deleted.
-        """
 
+        """
         for content in self[self.resource_type]:
             if self.resource_type == DBTResourceType.SOURCE.value:
                 for table in content["tables"]:
@@ -422,7 +430,7 @@ class DBTProperties(dict):
         description: str,
         tags: list[str],
         quote: bool,
-        tests: Optional[list[str]],
+        tests: list[str] | None,
     ) -> None:
         """Update a column in a YAML file.
 
@@ -442,6 +450,7 @@ class DBTProperties(dict):
                 Defaults to True.
             tests (list[str] or None, optional): List of tests associated
                 with the column. Defaults to None.
+
         """
         self.delete_column(
             table_name=table_name,
@@ -475,6 +484,7 @@ class DBTProperties(dict):
             db_columns (dict[str, str]): Columns and data types from
                 the database schema.
             table_name (str): Name of the table being synchronized.
+
         """
         db_column_names = list(db_columns.keys())
 
