@@ -458,7 +458,14 @@ def setup_source(request, TEST_SOURCE):
     shutil.rmtree(schema_path.parent, ignore_errors=True)
 
 
-@pytest.fixture(params=[TestData.base_model_props])
+@pytest.fixture(
+    params=[
+        (
+            {"model_props": TestData.base_model_props},
+            {"silver_schema": config.silver_schema},
+        )
+    ],
+)
 def setup_base_model(
     request,
     setup_source,
@@ -468,8 +475,16 @@ def setup_base_model(
     TEST_TABLE_ACCOUNT,
     TEST_TABLE_ACCOUNT_BASE_MODEL,
 ):
+    # Handle the very strange way fixture params work in pytest.
+    if isinstance(request.param, tuple):
+        model_props = request.param[0]["model_props"]
+        silver_schema = request.param[1]["silver_schema"]
+    else:
+        model_props = request.param["model_props"]
+        silver_schema = request.param["silver_schema"]
+
     base_model_path = (
-        PROJECT_DIR / "models" / config.silver_schema / TEST_TABLE_ACCOUNT_BASE_MODEL
+        PROJECT_DIR / "models" / silver_schema / TEST_TABLE_ACCOUNT_BASE_MODEL
     )
     base_model_file_yml = base_model_path / f"{TEST_TABLE_ACCOUNT_BASE_MODEL}.yml"
     base_model_file_sql = base_model_path / f"{TEST_TABLE_ACCOUNT_BASE_MODEL}.sql"
@@ -487,7 +502,7 @@ def setup_base_model(
     )
 
     with open(base_model_file_yml, "w") as file:
-        yaml.dump(request.param, file)
+        yaml.dump(model_props, file)
 
     yield base_model_file_yml
 
